--[[ NOTES

]]

--**************************************************
-- addon globals

local gsub, strfind, strlower, tonumber, tostring, random, floor, ceil, strsub, sqrt, abs, print, pairs, tinsert = gsub, strfind, strlower, tonumber, tostring, random, floor, ceil, strsub, sqrt, abs, print, pairs, tinsert

local addonTag = "\124cffffcc00[MoosePacCraft]:\124r"
local GhostyTextureSets = {
	["teal"] = {
		["right"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_right1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_right2",},
		["left"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_left1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_left2",},
		["up"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_up1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_up2",},
		["down"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_down1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_teal_down2",},
		["feared"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee2"}
	},
	["red"] = {
		["right"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_right1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_right2",},
		["left"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_left1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_left2",},
		["up"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_up1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_up2",},
		["down"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_down1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_red_down2",},
		["feared"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee2"}
	},
	["purple"] = {
		["right"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_right1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_right2",},
		["left"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_left1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_left2",},
		["up"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_up1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_up2",},
		["down"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_down1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_purple_down2",},
		["feared"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee2"}
	},
	["pink"] = {
		["right"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_right1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_right2",},
		["left"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_left1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_left2",},
		["up"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_up1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_up2",},
		["down"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_down1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_pink_down2",},
		["feared"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee2"}
	},
	["yellow"] = {
		["right"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_right1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_right2",},
		["left"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_left1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_left2",},
		["up"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_up1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_up2",},
		["down"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_down1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_yellow_down2",},
		["feared"] = {"Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee1","Interface\\AddOns\\MoosePacCraft\\pacsprites\\ghost_flee2"}
	},
}
local DefaultMaps = {
	["default1"] = {
		--if [x][1] is greater than [x][2], the values will be swapped when the path is created
		--Paths[int(x)] is allowed to hold one or two cell numbers.  if two numbers are specified, the frame will be created with the topleft point paths[x][1] and bottomright paths[x][2]
		--INTEGER KEYS ARE RESERVED FOR CELL COORDINATES.  DO NOT USE THEM FOR MAP PROPERTIES.  USE STRINGS FOR THOSE INSTEAD.
		--cells start with 0 (topleft cell)
		--properties
		["title"] = "default1",
		["columns"] = 15,		-- number of cells per row
		["rows"] = 20,	-- number of cells per column
		["length"] = 20,				--length of the cells' sides (they're always square),
		["playerEntry"] = 247,		--the cell which the player starts on
		["enemyHolding"] = 172,		--the cell (usually a wall) where the enemies are contained before they are released. a special, non-pathable frame is created here to prevent movement, do not place on path
		["enemyEntry"] = 142,			--cell where enemies are released and start moving
		--pathing cells
		16,17,18,19,20,21,22,23,24,25,26,27,28,31,37,43,46,47,48,49,51,52,53,55,56,57,58,61,64,65,66,68,69,70,73,76,78,79,81,82,83,85,86,88,91,93,96,98,101,103,106,108,111,113,116,118,121,122,123,124,126,128,130,131,132,133,136,139,140,141,142,143,144,145,148,151,154,160,163,166,169,175,178,181,182,183,184,190,191,192,193,196,199,200,201,202,203,204,205,208,211,215,217,219,223,226,227,228,229,230,232,234,235,236,237,238,241,243,245,246,247,248,249,251,253,256,258,262,266,268,271,272,273,274,275,276,277,278,279,280,281,282,283,
	},
	["default2"] = {
		0,1,2,4,5,6,7,8,9,10,12,13,14,15,17,18,19,25,26,27,29,30,31,32,34,35,36,37,38,39,40,42,43,44,45,52,59,60,62,63,64,65,67,69,70,71,72,74,75,76,77,80,81,82,83,84,87,88,89,90,92,93,94,95,97,99,100,101,102,104,105,108,112,116,119,120,122,123,124,125,127,129,130,131,132,134,135,137,140,142,144,147,149,150,152,155,156,157,158,159,162,164,165,166,167,168,169,170,172,174,175,176,177,178,179,180,184,190,194,195,199,205,209,210,211,212,213,214,215,216,217,218,219,220,221,222,223,224,225,227,230,234,237,239,240,242,245,249,252,254,255,256,257,259,260,261,262,263,264,265,267,268,269,270,272,273,274,280,281,282,284,285,286,287,289,290,291,292,293,294,295,297,298,299,
		["enemyHolding"] = 172,
		["columns"] = 15,
		["playerEntry"] = 217,
		["enemyEntry"] = 157,
		["rows"] = 20,
		["title"] = "default2",
		["length"] = 20,
	},

}
--**************************************************
function RoundRealToInt(n)
	if (n - floor(n)) >= .5 then return ceil(n) else return floor(n) end
end

function tblContains(tbl,item)	--replacement for blizzard's fail tContains()
	for k,v in pairs(tbl) do
		if tbl[k] == item then return true end
	end
	return false
end

function tinsertAll(tbl,items)	--***WARNING: does NOT preserve table keys***
	for k,v in pairs(items) do
		tinsert(tbl,v)
	end
end

function GetRandomGhostyTextureSet()
	local r = random(1,5)
	if r  == 1 then
		return GhostyTextureSets.teal
	elseif r == 2 then
		return GhostyTextureSets.red
	elseif r == 3 then
		return GhostyTextureSets.purple
	elseif r == 4 then
		return GhostyTextureSets.pink
	elseif r == 5 then
		return GhostyTextureSets.yellow
	end
end

function PacCraft_GetDefaultMaps()	--getter function
	return DefaultMaps
end


--[[<!--
<Frame name="MoosePacCraftOptionsFrame" parent="UIParent" enableMouse="true" hidden="true" frameStrata="DIALOG" >

	<Anchors><Anchor point="CENTER" /></Anchors>
	<Size x="500" y="600" />
	
	<Layers>
		<Layer level="BACKGROUND"><Texture name="$parent_BGTexture" setAllPoints="true"><Color r="0" g="0" b="0" a="1" /></Texture></Layer>
	</Layers>

	<Frames>

		<Frame name="$parent_TitleFrame" >
			<Anchors>
				<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" x="0" y="-4"/>
				<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="TOPRIGHT" x="0" y="-24"/>
			</Anchors>
			
			<Layers>
				<Layer level="BACKGROUND">
					<Texture name="$parent_BGTexture" setAllPoints="true">
						<Color r="0" g="0" b="0" a="0" />
					</Texture>
				</Layer>
				<Layer level="OVERLAY">
					<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="CENTER" justifyV="MIDDLE" text="[MoosePacCraft Options]" setAllPoints="true" ></FontString>
				</Layer>
			</Layers>
		</Frame>
		
		<Frame name="$parent_Border" >
		<Anchors>
			<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" x="-3" y="3" />
			<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="3" y="-3" />
		</Anchors>
			<Backdrop edgeFile="Interface/Tooltips/UI-Tooltip-Border" >
				<EdgeSize><AbsValue val="12"/></EdgeSize>
				<BackgroundInsets><AbsInset left="0" right="0" top="0" bottom="0"/></BackgroundInsets>
			</Backdrop>
			<Scripts>
				<OnLoad>
					self:Lower()
				</OnLoad>
			</Scripts>
		</Frame>
		
		<Button name="$parent_OkayButton" inherits="GameMenuButtonTemplate" text="Okay" >
			<Size x="72" y="20" />
			<Anchors>
				<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-4" y="4" />
			</Anchors>
			<Scripts>
				<OnClick>
					TetrisGameBoard.isKeybindingMode = false
					--print(self:GetName().." OnClick handler.")
					--self:GetParent():SaveOptions()
					self:GetParent():Hide()
					--TetrisGameBoard:UnPause(true)
					--TetrisGameBoard_PauseButton.checked = false
				</OnClick>
			</Scripts>
		</Button>

		<Frame name="$parent_KeybindsFrame" >
			<Anchors>
				<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" x="2" y="-64" />
				<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="TOPRIGHT" x="-2" y="-224" />
			</Anchors>
			
			<Layers>
				<Layer level="BACKGROUND">
					<Texture name="$parent_BGTexture" setAllPoints="true">
						<Color r="1" g="1" b="1" a=".5" />
					</Texture>
				</Layer>
				<Layer level="OVERLAY">
					<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="CENTER" justifyV="MIDDLE" text="Keybinds" >
						<Anchors><Anchor point="BOTTOMLEFT" relativeTo="$parent" relativePoint="TOPLEFT" x="2" y="4" /></Anchors>
					</FontString>
				</Layer>
			</Layers>
		
			<Frames>
				<Frame name="$parent_CloseGameWindowFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="TOPRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Close Window: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Close Game Window key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.close = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.close)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.close)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_LeftBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_CloseGameWindowFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_CloseGameWindowFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Move Left: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Move Left key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.left = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.left)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.left)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_RightBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_LeftBindFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_LeftBindFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Move Right: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Move Right key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.right = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.right)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.right)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_DownBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_RightBindFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_RightBindFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Move Down: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Move Down key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.down = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.down)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.down)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_RotateCounterBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_DownBindFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_DownBindFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Rotate counter-clockwise: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Rotate Counter-Clockwise key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.rotateCounter = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.rotateCounter)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.rotateCounter)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_RotateClockBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_RotateCounterBindFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_RotateCounterBindFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Layers>
						<Layer level="OVERLAY">
							<FontString name="$parent_Text" inherits="GameFontNormal" justifyH="RIGHT" justifyV="MIDDLE" text="Rotate clockwise: " >
								<Anchors>
									<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" />
									<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" />
								</Anchors>
							</FontString>
						</Layer>
					</Layers>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="?" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOP" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOMRIGHT" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press a key to bind.")
									self:SetScript("OnKeyDown",function(self,key)
										print("\124cffffcc00[Tetris]:\124r Rotate Clockwise key set to \124r"..key)
										MOOSETETRIS_OPTIONS.keybinds.rotateClock = key
										self:SetText(MOOSETETRIS_OPTIONS.keybinds.rotateClock)
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
								<OnShow>
									self:SetText(MOOSETETRIS_OPTIONS.keybinds.rotateClock)
								</OnShow>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
				<Frame name="$parent_SetDefaultBindFrame">
					<Anchors>
						<Anchor point="TOPLEFT" relativeTo="$parent_RotateClockBindFrame" relativePoint="BOTTOMLEFT" />
						<Anchor point="BOTTOMRIGHT" relativeTo="$parent_RotateClockBindFrame" relativePoint="BOTTOMRIGHT" y="-20" />
					</Anchors>
					<Frames>
						<Button name="$parent_KeybindButton" inherits="UIPanelButtonTemplate" text="Reset to Defaults" >
							<Anchors>
								<Anchor point="TOPLEFT" relativeTo="$parent" relativePoint="TOPLEFT" x="8" y="-2" />
								<Anchor point="BOTTOMRIGHT" relativeTo="$parent" relativePoint="BOTTOM" x="-8" y="2" />
							</Anchors>
							<Scripts>
								<OnClick>
									Tetris_CloseAllKeybindButtons()
									self:SetText("Press ENTER to confirm.")
									self:SetScript("OnKeyDown",function(self,key)
										if key == "ENTER" then
											Tetris_ResetKeybinds()
										end
										self:SetText("Reset to Defaults")
										self:SetScript("OnKeyDown",nil)
									end)
								</OnClick>
							</Scripts>
						</Button>
					</Frames>
				</Frame>
				
			</Frames>
			
			
		</Frame>
	</Frames>
</Frame>-->]]


